@@ -1,6 +1,6 @@
 # Natural Language Toolkit: Tokenizers
 #
-# Copyright (C) 2001-2018 NLTK Project
+# Copyright (C) 2001-2019 NLTK Project
 # Author: Yoav Goldberg <yoavg@cs.bgu.ac.il>
 #         Steven Bird <stevenbird1@gmail.com> (minor edits)
 # URL: <http://nltk.sourceforge.net>
@@ -82,8 +82,9 @@ class SExprTokenizer(TokenizerI):
         self._strict = strict
         self._open_paren = parens[0]
         self._close_paren = parens[1]
-        self._paren_regexp = re.compile('%s|%s' % (re.escape(parens[0]),
-                                                   re.escape(parens[1])))
+        self._paren_regexp = re.compile(
+            '%s|%s' % (re.escape(parens[0]), re.escape(parens[1]))
+        )
 
     def tokenize(self, text):
         """
@@ -118,17 +119,16 @@ class SExprTokenizer(TokenizerI):
         for m in self._paren_regexp.finditer(text):
             paren = m.group()
             if depth == 0:
-                result += text[pos:m.start()].split()
+                result += text[pos : m.start()].split()
                 pos = m.start()
             if paren == self._open_paren:
                 depth += 1
             if paren == self._close_paren:
                 if self._strict and depth == 0:
-                    raise ValueError('Un-matched close paren at char %d'
-                                     % m.start())
+                    raise ValueError('Un-matched close paren at char %d' % m.start())
                 depth = max(0, depth - 1)
                 if depth == 0:
-                    result.append(text[pos:m.end()])
+                    result.append(text[pos : m.end()])
                     pos = m.end()
         if self._strict and depth > 0:
             raise ValueError('Un-matched open paren at char %d' % pos)
